## **What is `lumaCLI`?**

`lumaCLI` is the [CLI](https://www.w3schools.com/whatis/whatis_cli.asp) for the **Luma Data Catalog**.

This versatile tool empowers users to:

- [x] Ingest dbt data (like metadata or test results) to the Luma Data Catalog.
- [x] Ingest metadata of a PostgreSQL database to the Luma Data Catalog.
- [x] Update configurations in the Luma Data Catalog swiftly and easily, directly from the command line.

To kickstart your journey with `lumaCLI`, please visit the [Getting Started](./getting_started.md) section.
